==> lesstif_0.50.orig.tar.gz: lesstif-0.50.orig/include/Xm/MenuShellP.h <==
/**
 *
 * $Id: MenuShellP.h,v 1.4 1996/04/03 05:03:52 miers Exp $
 *
 * Copyright (C) 1995 Free Software Foundation, Inc.
 *
 * This file is part of the GNU LessTif Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **/

#ifndef XM_MENUSHELL_P_H
#define XM_MENUSHELL_P_H

#include <Xm/XmP.h>
#include <Xm/MenuShell.h>
#include <X11/ShellP.h>

#ifdef __cplusplus
extern "C" {
#endif

/* define the menushell instance part */
typedef struct {
    unsigned char focus_policy;
    XmFocusData focus_data;
    Boolean private_shell;
    XmFontList default_font_list;
    XmFontList button_font_list;
    XmFontList label_font_list;
} XmMenuShellPart;

/* define the full instance record */
typedef struct _XmMenuShellRec {
    CorePart core;
    CompositePart composite;
    ShellPart shell;
    OverrideShellPart override;
    XmMenuShellPart menu_shell;
} XmMenuShellRec;

/* define class part structure */
typedef struct {
    XtActionProc popdownOne;
    XtActionProc popdownEveryone;
    XtActionProc popdownDone;
    XmMenuPopupProc popuSharedMenupane;
    XtPointer extension;
} XmMenuShellClassPart;

/* define the full class record */
typedef struct _XmMenuShellClassRec {
    CoreClassPart core_class;
    CompositeClassPart composite_class;
    ShellClassPart shell_class;
    OverrideShellClassPart override_shell_class;
    XmMenuShellClassPart menu_shell_class;
} XmMenuShellClassRec;

extern XmMenuShellClassRec xmMenuShellClassRec;

#define MS_LabelFontList(w) \
	(((XmMenuShellWidget)w)->menu_shell.label_font_list)

#define MS_ButtonFontList(w) \
	(((XmMenuShellWidget)w)->menu_shell.button_font_list)

#define MS_DefaultFontList(w) \
	(((XmMenuShellWidget)w)->menu_shell.default_font_list)

#define MS_FocusPolicy(w) \
	(((XmMenuShellWidget)w)->menu_shell.focus_policy)

#define MS_FocusData(w) \
	(((XmMenuShellWidget)w)->menu_shell.focus_data)

#define MS_PrivateShell(w) \
	(((XmMenuShellWidget)w)->menu_shell.private_shell)

void _XmEnterRowColumn(Widget widget,
		       XtPointer closure,
		       XEvent *event,
		       Boolean *cont);
void _XmClearTraversal(Widget wid,
		       XEvent *event,
		       String *params,
		       Cardinal *num_params);
void _XmSetLastManagedMenuTime(Widget wid, Time newTime);

#ifdef __cplusplus
};
#endif

#endif /* XM_MENUSHELL_P_H */

==> lesstif_0.76.orig.tar.gz: lesstif-0.76.orig/include/Xm/MenuShellP.h <==
/**
 *
 * $Id: MenuShellP.h,v 1.4 1996/08/29 00:06:31 miers Exp $
 *
 * Copyright (C) 1995 Free Software Foundation, Inc.
 *
 * This file is part of the GNU LessTif Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **/

#ifndef XM_MENUSHELL_P_H
#define XM_MENUSHELL_P_H

#include <Xm/XmP.h>
#include <Xm/MenuShell.h>
#include <X11/ShellP.h>

#ifdef __cplusplus
extern "C" {
#endif

/* define the menushell instance part */
typedef struct {
    unsigned char focus_policy;
    XmFocusData focus_data;
    Boolean private_shell;
    XmFontList default_font_list;
    XmFontList button_font_list;
    XmFontList label_font_list;
} XmMenuShellPart;

/* define the full instance record */
typedef struct _XmMenuShellRec {
    CorePart core;
    CompositePart composite;
    ShellPart shell;
    OverrideShellPart override;
    XmMenuShellPart menu_shell;
} XmMenuShellRec;

/* define class part structure */
typedef struct {
    XtActionProc popdownOne;
    XtActionProc popdownEveryone;
    XtActionProc popdownDone;
    XmMenuPopupProc popupSharedMenupane;
    XtPointer extension;
} XmMenuShellClassPart;

/* define the full class record */
typedef struct _XmMenuShellClassRec {
    CoreClassPart core_class;
    CompositeClassPart composite_class;
    ShellClassPart shell_class;
    OverrideShellClassPart override_shell_class;
    XmMenuShellClassPart menu_shell_class;
} XmMenuShellClassRec;

extern XmMenuShellClassRec xmMenuShellClassRec;

void _XmEnterRowColumn(Widget widget,
		       XtPointer closure,
		       XEvent *event,
		       Boolean *cont);
void _XmClearTraversal(Widget wid,
		       XEvent *event,
		       String *params,
		       Cardinal *num_params);
void _XmSetLastManagedMenuTime(Widget wid, Time newTime);

#define MS_FocusPolicy(w) \
	(((XmMenuShellWidget)w)->menu_shell.focus_policy)

#ifdef __cplusplus
}
#endif

#endif /* XM_MENUSHELL_P_H */
